@@ -1,4 +1,4 @@
-// Copyright 2004 "Gilles Degottex"
+﻿// Copyright 2004 "Gilles Degottex"
 
 // This file is part of "Music"
 
@@ -63,7 +63,8 @@ class CaptureThreadImpl
 	virtual void stopCapture()=0;
 	virtual bool is_available()=0;
 
-	double (*decodeValue)(void* buffer, int i);
+    double m_tmp_value; // used when two channels have to be mixed down
+	double (*decodeValue)(void* buffer, int i); // not used for JACK
 	void (*addValue)(CaptureThreadImpl* impl, double value, int i);
 	void setFormatDescrsAndFns(int format_size, bool format_signed, bool format_float, int channel_count);
 
@@ -75,10 +76,50 @@ class CaptureThreadImpl
 	const QString& getName() const {return m_name;}
 	const QString& getDescription() const {return m_descr;}
 	const QString& getSource() const {return m_source;}
+    QString getASCIISource() const;
 
 	virtual ~CaptureThreadImpl(){}
 };
 
+// ---------------------- the Qt implementation ---------------------
+
+#ifdef CAPTURE_QT
+#include <QAudioDeviceInfo>
+#include <QAudioInput>
+class CaptureThreadImplQt : public QObject, public CaptureThreadImpl
+{
+    Q_OBJECT
+
+    void set_params(bool test=false);
+
+    void capture_init();
+    void capture_finished();
+
+    const QList<QAudioDeviceInfo> m_availableAudioInputDevices;
+    QAudioDeviceInfo    m_audioInputDevice;
+    QAudioInput*        m_audioInput;
+    QIODevice*          m_audioInputIODevice;
+
+    QAudio::State       m_state;
+
+    QAudioFormat        m_format;
+
+  public:
+    CaptureThreadImplQt(CaptureThread* capture_thread);
+
+    virtual void setSamplingRate(int rate);
+    virtual void startCapture();
+    virtual void stopCapture();
+    virtual bool is_available();
+
+    ~CaptureThreadImplQt();
+
+public slots:
+    void audioStateChanged(QAudio::State state);
+    void audioDataReady();
+};
+#endif
+
 // ---------------------- the ALSA implementation ---------------------
 
 #ifdef CAPTURE_ALSA
@@ -121,21 +162,34 @@ class CaptureThreadImplALSA : public CaptureThreadImpl, public QThread
 
 #ifdef CAPTURE_JACK
 #include <jack/jack.h>
-class CaptureThreadImplJACK : public CaptureThreadImpl
+#include <jack/ringbuffer.h>
+class CaptureThreadImplJACK : public CaptureThreadImpl, public QThread
 {
 	static int JackProcess(jack_nframes_t nframes, void* arg);
 	static void JackShutdown(void* arg);
 	static int JackSampleRate(jack_nframes_t nframes, void* arg);
 
+    jack_ringbuffer_t* m_ringbuffer;
 	jack_client_t* m_jack_client;
 	jack_port_t* m_jack_port;
 	int jackSampleRate(jack_nframes_t nframes);
 	int jackProcess(jack_nframes_t nframes);
 	void jackShutdown();
 
-	void capture_init();
+    // view
+    volatile bool m_alive;
+    volatile bool m_in_run;
+
+    // control
+    volatile bool m_loop;
+    volatile bool m_wait_for_start;
+
+    void capture_init();
+    void capture_loop();
 	void capture_finished();
 
+    virtual void run();
+
   public:
 	CaptureThreadImplJACK(CaptureThread* capture_thread);
 
@@ -143,6 +197,8 @@ class CaptureThreadImplJACK : public CaptureThreadImpl
 	virtual void startCapture();
 	virtual void stopCapture();
 	virtual bool is_available();
+    
+    ~CaptureThreadImplJACK();
 };
 #endif
 
@@ -225,6 +281,9 @@ class CaptureThread : public QObject
 	Q_OBJECT
 
 	friend class CaptureThreadImpl;
+#ifdef CAPTURE_QT
+    friend class CaptureThreadImplQt;
+#endif
 #ifdef CAPTURE_ALSA
 	friend class CaptureThreadImplALSA;
 #endif
@@ -275,7 +334,7 @@ class CaptureThread : public QObject
 	int getSamplingRate() const;
 	int getPacketSize() const						{return m_packet_size;}
 	int getPacketSizeSinceLastLock() const			{return m_packet_size_sll;}
-	int getNbPendingData() const					{return m_values.size();}
+    int getNbPendingData() const					{return int(m_values.size());}
 	const CaptureThreadImpl* getCurrentTransport() const;
 	int getCurrentTransportIndex() const;
 	QString getCurrentTransportDescr() const;
