@@ -106,6 +106,11 @@ CustomInstrumentTunerForm::CustomInstrumentTunerForm()
 	m_settings.add(m_config_form.ui_spinPortAudioSamplingRate);
 	m_settings.add(m_config_form.ui_chkPortAudioMixMultipleChannels);
 #endif
+#ifdef CAPTURE_QT
+    m_settings.add(m_config_form.ui_chkQtSamplingRateMax);
+    m_settings.add(m_config_form.ui_spinQtSamplingRate);
+    m_settings.add(m_config_form.ui_chkQtMixMultipleChannels);
+#endif
 
 	m_settings.add(m_config_form.ui_spinRefreshTime);
 	m_settings.add(m_config_form.ui_spinMinHT);
@@ -1157,6 +1162,9 @@ void CustomInstrumentTunerForm::helpAbout()
 //	about_dlg.exec();
 }
 
+void CustomInstrumentTunerForm::closeEvent( QCloseEvent* event ){
+    m_config_form.close();
+}
 CustomInstrumentTunerForm::~CustomInstrumentTunerForm()
 {
 	if(m_config_form.ui_chkAutoSaveOnExit->isChecked())
@@ -1184,14 +1192,14 @@ void CustomInstrumentTunerForm::update_localized_note_names()
 
 	QString a4Name = QString::fromStdString(h2n(0, GetNotesName(), 0, CHROMATIC, true));
 
-	QString a4FreqToolTip = tr("The base tunning frequency (the %1 frequency)")
+	QString a4FreqToolTip = tr("The base tuning frequency (the %1 frequency)")
 			.arg(a4Name);
 	textLabel8->setToolTip(a4FreqToolTip);
 	textLabel8->setWhatsThis(a4FreqToolTip);
 	ui_spinAFreq->setToolTip(a4FreqToolTip);
 	ui_spinAFreq->setWhatsThis(a4FreqToolTip);
 
-	QString showA4OffsetText = tr("Allows to add an offset to the reference %1")
+	QString showA4OffsetText = tr("Allows adding an offset to the reference %1")
 			.arg(a4Name);
 	m_config_form.ui_chkShowA4Offset->setText(showA4OffsetText);
 
