@@ -35,7 +35,7 @@ LatencyMonoQuantizer::LatencyMonoQuantizer()
 
 void LatencyMonoQuantizer::quantize(double freq)
 {
-// 	cerr << "LatencyMonoQuantizer::quantize " << freq << " m_states=" << m_states.size() << endl;
+// 	cout << "LatencyMonoQuantizer::quantize " << freq << " m_states=" << m_states.size() << endl;
 
 	double current_time = m_time.elapsed();
 
@@ -45,7 +45,7 @@ void LatencyMonoQuantizer::quantize(double freq)
 	int max_dens = 1;
 	m_avg_freq = freq;
 	map<double,Note> densities;
-	for(int i=0; i<m_states.size(); i++)
+    for(int i=0; i<int(m_states.size()); i++)
 	{
 		double cf = f2cf(m_states[i].m_freq);
 		map<double,Note>::iterator it=densities.find(cf);
@@ -66,7 +66,7 @@ void LatencyMonoQuantizer::quantize(double freq)
 		}
 	}
 
-// 	cerr << m_current_center_freq << ", " << current_center_freq << ", " << m_avg_freq << ", max_dens=" << max_dens << ", m_states.size()=" << m_states.size() << endl;
+// 	cout << m_current_center_freq << ", " << current_center_freq << ", " << m_avg_freq << ", max_dens=" << max_dens << ", m_states.size()=" << m_states.size() << endl;
 
 	m_confidence = double(max_dens)/m_states.size();
 
