@@ -23,7 +23,7 @@
 
 #include <deque>
 using namespace std;
-#include <qgl.h>
+#include <QOpenGLWidget>
 #include <qspinbox.h>
 #include <qsettings.h>
 #include <qaction.h>
@@ -31,12 +31,14 @@ class QTimer;
 #include <Music/Music.h>
 #include "View.h"
 
-class GLErrorHistory : public QGLWidget, public View
+class GLErrorHistory : public QOpenGLWidget, public View
 {
 	Q_OBJECT
 
 	virtual void mouseReleaseEvent(QMouseEvent* e){View::mouseReleaseEvent(e);}
 
+    QFont m_font;
+
 	void drawTicksCent(int r, int ticks_size);
 	void drawTextTickCent(int r, int dy);
 
@@ -74,6 +76,7 @@ class GLErrorHistory : public QGLWidget, public View
 	void initializeGL();
 	void paintGL();
 	void resizeGL( int w, int h );
+//    void paintEvent(QPaintEvent * event);
 	void keepPreviousNotes(bool keep);
 };
 
