@@ -6,22 +6,22 @@
     <message>
         <location filename="../ui/aboutbox.ui" line="14"/>
         <source>About FMIT...</source>
-        <translation type="unfinished"></translation>
+        <translation>Über FMIT...</translation>
     </message>
     <message>
         <location filename="../ui/aboutbox.ui" line="28"/>
         <source>About</source>
-        <translation type="unfinished">Über</translation>
+        <translation>Über</translation>
     </message>
     <message>
         <location filename="../ui/aboutbox.ui" line="88"/>
         <source>FMIT</source>
-        <translation type="unfinished"></translation>
+        <translation>FMIT</translation>
     </message>
     <message>
         <location filename="../ui/aboutbox.ui" line="98"/>
         <source>&lt;version&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;version&gt;</translation>
     </message>
     <message>
         <location filename="../ui/aboutbox.ui" line="123"/>
@@ -30,12 +30,16 @@
 p, li { white-space: pre-wrap; }
 &lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Ubuntu&apos;; font-size:11pt; font-weight:400; font-style:normal;&quot;&gt;
 &lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
+&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
+p, li { white-space: pre-wrap; }
+&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Ubuntu&apos;; font-size:11pt; font-weight:400; font-style:normal;&quot;&gt;
+&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
         <location filename="../ui/aboutbox.ui" line="143"/>
         <source>Credits</source>
-        <translation type="unfinished"></translation>
+        <translation>Beitragende</translation>
     </message>
     <message>
         <location filename="../ui/aboutbox.ui" line="158"/>
@@ -50,7 +54,17 @@ p, li { white-space: pre-wrap; }
 &lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- Scott Bahling for the scales in cents&lt;/p&gt;
 &lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- Jacob Shapiro for his help to make FMIT working under Windows/Cygwin.&lt;/p&gt;
 &lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;- Translators: Omega9 (Russian), skarmoutsosv (Greek), Pindaro and dsboger (Portuguese and Brazilian Portuguese), Florian Maier (German).&lt;br /&gt;&lt;br /&gt;- &lt;a href=&quot;http://www.fftw.org/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;FFTW3&lt;/span&gt;&lt;/a&gt;&apos; for the very Fast Fourier Transform.&lt;br /&gt;&lt;br /&gt;- &lt;a href=&quot;http://www.qt.io/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Qt&lt;/span&gt;&lt;/a&gt;&apos;s team for the GUI library.&lt;br /&gt;&lt;br /&gt;Any contribution of any sort is very welcome!&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
+&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
+p, li { white-space: pre-wrap; }
+&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Ubuntu&apos;; font-size:11pt; font-weight:400; font-style:normal;&quot;&gt;
+&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Die meiste Open-Source-Software ist ohne indirekte Beiträge, die über Bibliotheken bereitgestellt werden, nicht machbar. Deshalb geht ein großes Dankeschön an die folgenden Geeks:&lt;br /&gt;&lt;br /&gt;-dsboger für so viele kleine und nützliche Änderungen, Updates, Verpackungen, etc.&lt;/p&gt;
+&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;-Florian Hars for the tunning scales&lt;/p&gt;
+&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- Arnout Engelen for the JACK issues&lt;/p&gt;
+&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- John Anderson for the microtonal module idea&lt;/p&gt;
+&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;-Scott Bahling für die Skalen in Cent&lt;/p&gt;
+&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;-Jacob Shapiro für seine Hilfe, FMIT unter Windows/Cygwin zum Laufen zu bringen.&lt;/p&gt;
+&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;-Übersetzer: Omega9 (Russisch), Skarmoutsosv (griechisch), Pindaro und dsboger (Portugiesisch), Florian Maier (Deutsch).&lt;br /&gt;&lt;br /&gt;- &lt;a href=&quot;http://www.fftw.org/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;FFTW3&lt;/span&gt;&lt;/a&gt;&apos; für die sehr schnelle Fourier-Transformation.&lt;br /&gt;&lt;br /&gt;- &lt;a href=&quot;http://www.qt.io/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Qt&lt;/span&gt;&lt;/a&gt; Team für die GUI-Bibliothek.&lt;br /&gt;&lt;br /&gt;Jeder Beitrag jeglicher Art ist sehr willkommen!&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
 </context>
 <context>
@@ -186,7 +200,9 @@ Romanisch: Do Re Mi Fa Sol La Si</translation>
         <source>Use localized note names. e.g.:
 anglo-saxon: C D E F G A B
 latin: Do Re Mi Fa Sol La Si</source>
-        <translation type="unfinished"></translation>
+        <translation>Verwenden Sie lokalisierte Notennamen, z.B:
+angelsächsisch: C D E F G A B
+Latein: Do Re Mi Fa Sol La Si</translation>
     </message>
     <message>
         <location filename="../ui/ConfigForm.ui" line="457"/>
@@ -276,17 +292,17 @@ Wird verwendet um Tonnamen auf ein bestimmtes Instrument umzusetzen (z.B. Eb fü
     <message>
         <location filename="../ui/ConfigForm.ui" line="198"/>
         <source>German</source>
-        <translation type="unfinished"></translation>
+        <translation>Deutsch</translation>
     </message>
     <message>
         <location filename="../ui/ConfigForm.ui" line="203"/>
         <source>Hindustani</source>
-        <translation type="unfinished"></translation>
+        <translation>Swara-Natation</translation>
     </message>
     <message>
         <location filename="../ui/ConfigForm.ui" line="208"/>
         <source>Byzantine</source>
-        <translation type="unfinished"></translation>
+        <translation>Byzantinische Notation</translation>
     </message>
     <message>
         <location filename="../ui/ConfigForm.ui" line="274"/>
@@ -400,7 +416,7 @@ Verwenden Sie keine zu hohe Abtastrate. 22050Hz sollten in den meisten Fällen a
     <message>
         <location filename="../ui/ConfigForm.ui" line="787"/>
         <source>Qt</source>
-        <translation type="unfinished"></translation>
+        <translation>Qt</translation>
     </message>
     <message>
         <location filename="../ui/ConfigForm.ui" line="916"/>
@@ -523,7 +539,7 @@ Je geringer der Wert, desto schneller das Stimmgerät. Jedoch wird die berechnet
     <message>
         <location filename="../ui/ConfigForm.ui" line="128"/>
         <source>Transposition</source>
-        <translation type="unfinished"></translation>
+        <translation>Transponierung</translation>
     </message>
     <message>
         <location filename="../ui/ConfigForm.ui" line="238"/>
@@ -532,7 +548,11 @@ Je geringer der Wert, desto schneller das Stimmgerät. Jedoch wird die berechnet
 p, li { white-space: pre-wrap; }
 &lt;/style&gt;&lt;/head&gt;&lt;body&gt;
 &lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;To get more options, right-click every view to show up their properties!&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
+&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
+p, li { white-space: pre-wrap; }
+&lt;/style&gt;&lt;/head&gt;&lt;body&gt;
+&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Weitere Optionen sind mittels Rechtsklick zugängig!&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
         <location filename="../ui/ConfigForm.ui" line="947"/>
@@ -687,34 +707,37 @@ Sollen Ihre aktuellen Einstellungen verworfen werden?</translation>
         <location filename="../src/CustomInstrumentTunerForm.cpp" line="1174"/>
         <source>Transposition in number of semitones relative to %1.
 Useful to convert note names to a corresponding transposing instrument (e.g. %2 for saxophone, %3 for trumpet).</source>
-        <translation type="unfinished"></translation>
+        <translation>Transposition in Halbtönen relativ zu %1.
+Nützlich um Notennamen für ein transponierendes Instrument umzuwandeln (z.B. %2 für Saxofon, %3 für Trompete).</translation>
     </message>
     <message>
         <location filename="../src/CustomInstrumentTunerForm.cpp" line="1187"/>
         <source>The base tunning frequency (the %1 frequency)</source>
-        <translation type="unfinished"></translation>
+        <translation>Die grundlegende Stimmungsfrequenz (die %1 Frequenz)</translation>
     </message>
     <message>
         <location filename="../src/CustomInstrumentTunerForm.cpp" line="1194"/>
         <source>Allows to add an offset to the reference %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Ermöglicht eine Verschiebung zur Referenz %1</translation>
     </message>
     <message>
         <location filename="../src/CustomInstrumentTunerForm.cpp" line="1198"/>
         <source>Range of possible notes from the lowest to the highest around the %1 reference note.
 Smaller the range, smaller the CPU usage.</source>
-        <translation type="unfinished"></translation>
+        <translation>Tonumfang von der tiefsten zur höchsten Note um die Referenznote %1.
+Je geringer der Umfang, desto geringer ist die CPU-Belastung.</translation>
     </message>
     <message>
         <location filename="../src/CustomInstrumentTunerForm.cpp" line="1203"/>
         <source>Lowest semitone from the %1 reference note.
 It can useful to put it higher than -35 to avoid disturbance from the sector alimentation (~50hz).</source>
-        <translation type="unfinished"></translation>
+        <translation>Tiefster Halbton von der Referenznote %2.
+Ein Wert oberhalb von -35 kann zur Vermeidung von Störeinflüssen aufgrund der 50Hz-Wechselstrom-Netzfrequenz hilfreich sein.</translation>
     </message>
     <message>
         <location filename="../src/CustomInstrumentTunerForm.cpp" line="1210"/>
         <source>Highest semitone from the %1 reference note.</source>
-        <translation type="unfinished"></translation>
+        <translation>Höchster Halbton von der Referenznote %1 aus.</translation>
     </message>
 </context>
 <context>
@@ -838,7 +861,7 @@ It can useful to put it higher than -35 to avoid disturbance from the sector ali
     <message>
         <location filename="../src/modules/GLFreqStruct.cpp" line="182"/>
         <source>Harmonics&apos; amplitude</source>
-        <translation type="unfinished"></translation>
+        <translation>Oberton-Amplitude</translation>
     </message>
     <message>
         <location filename="../src/modules/GLFreqStruct.cpp" line="33"/>
@@ -888,7 +911,7 @@ It can useful to put it higher than -35 to avoid disturbance from the sector ali
     <message>
         <location filename="../src/modules/GLSample.cpp" line="34"/>
         <source>Waveform</source>
-        <translation type="unfinished"></translation>
+        <translation>Wellenform</translation>
     </message>
     <message>
         <location filename="../src/modules/GLSample.cpp" line="43"/>
@@ -904,7 +927,7 @@ It can useful to put it higher than -35 to avoid disturbance from the sector ali
     <message>
         <location filename="../src/modules/GLSample.cpp" line="127"/>
         <source>Waveform&apos;s period</source>
-        <translation type="unfinished"></translation>
+        <translation>Wellenform-Periode</translation>
     </message>
 </context>
 <context>
@@ -1009,7 +1032,7 @@ It can useful to put it higher than -35 to avoid disturbance from the sector ali
     <message>
         <location filename="../ui/InstrumentTunerForm.ui" line="14"/>
         <source>Free Music Instrument Tuner</source>
-        <translation></translation>
+        <translation>Kostenloser Musikinstrumentenstimmer</translation>
     </message>
     <message>
         <location filename="../ui/InstrumentTunerForm.ui" line="55"/>
@@ -1047,7 +1070,7 @@ p</source>
     <message>
         <location filename="../ui/InstrumentTunerForm.ui" line="284"/>
         <source> cents</source>
-        <translation></translation>
+        <translation> Cent</translation>
     </message>
     <message>
         <location filename="../ui/InstrumentTunerForm.ui" line="348"/>
@@ -1147,7 +1170,7 @@ Grün: Ein Ton wird analysiert und die Analysebedingungen sind gut.</translation
     <message>
         <location filename="../ui/InstrumentTunerForm.ui" line="453"/>
         <source>Space</source>
-        <translation></translation>
+        <translation>Leertaste</translation>
     </message>
     <message>
         <location filename="../ui/InstrumentTunerForm.ui" line="465"/>
@@ -1242,12 +1265,12 @@ Grün: Ein Ton wird analysiert und die Analysebedingungen sind gut.</translation
     <message>
         <location filename="../src/CaptureThread.cpp" line="368"/>
         <source>default</source>
-        <translation type="unfinished">default</translation>
+        <translation>Voreinstellung</translation>
     </message>
     <message>
         <location filename="../src/modules/View.cpp" line="86"/>
         <source>%1</source>
-        <translation type="unfinished"></translation>
+        <translation>%1</translation>
     </message>
 </context>
 </TS>
