@@ -57,7 +57,17 @@ p, li { white-space: pre-wrap; }
 &lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- Scott Bahling for the scales in cents&lt;/p&gt;
 &lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- Jacob Shapiro for his help to make FMIT working under Windows/Cygwin.&lt;/p&gt;
 &lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;- Translators: Omega9 (Russian), skarmoutsosv (Greek), Pindaro and dsboger (Portuguese and Brazilian Portuguese), Florian Maier (German).&lt;br /&gt;&lt;br /&gt;- &lt;a href=&quot;http://www.fftw.org/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;FFTW3&lt;/span&gt;&lt;/a&gt;&apos; for the very Fast Fourier Transform.&lt;br /&gt;&lt;br /&gt;- &lt;a href=&quot;http://www.qt.io/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Qt&lt;/span&gt;&lt;/a&gt;&apos;s team for the GUI library.&lt;br /&gt;&lt;br /&gt;Any contribution of any sort is very welcome!&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
+&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
+p, li { white-space: pre-wrap; }
+&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Ubuntu&apos;; font-size:11pt; font-weight:400; font-style:normal;&quot;&gt;
+&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;La plupart des logiciels à sources ouvertes sont infaisables sans des contributions indirectes fournies à travers des bibliothèques. Ainsi, un gros merci aux as de l&apos;informatique suivants :&lt;br /&gt;&lt;br /&gt;- dsboger pour tant de petites et utiles modifications, mise à jour, empaquetage,... etc.&lt;/p&gt;
+&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- Florian Hars pour les gammes d&apos;accordage&lt;/p&gt;
+&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- Arnout Engelen pour les soucis JACK&lt;/p&gt;
+&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- John Anderson pour l&apos;idée de module microtonal&lt;/p&gt;
+&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- Scott Bahling pour les gammes en centièmes&lt;/p&gt;
+&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- Jacob Shapiro pour son aide pour faire en sorte que FMIT fonctionne sous Windows/Cygwin.&lt;/p&gt;
+&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;- Traducteurs : Omega9 (russe), skarmoutsosv (grecque), Pindaro et dsboger (portugais et portugais du Brésil), Florian Maier (Allemand).&lt;br /&gt;&lt;br /&gt;- &lt;a href=&quot;http://www.fftw.org/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;FFTW3&lt;/span&gt;&lt;/a&gt;&apos; pour les transformées de Fourier très rapides.&lt;br /&gt;&lt;br /&gt;- &lt;a href=&quot;http://www.qt.io/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Qt&lt;/span&gt;&lt;/a&gt; et son équipe pour la bibliothèque graphique.&lt;br /&gt;&lt;br /&gt;Toute contribution de toute forme est vraiment bienvenue !&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
 </context>
 <context>
@@ -289,7 +299,8 @@ Choisissez le nombre d&apos;harmoniques à utiliser.</translation>
     <message>
         <source>Raise the window to the whole screen when the program is started
 (You can also use the shortcut &apos;f&apos;).</source>
-        <translation>Agrandit la fenêtre sur tout l&apos;écran lorsque le programme démarre (utilisez le raccourci &apos;f&apos;).</translation>
+        <translation>Agrandit la fenêtre sur tout l&apos;écran lorsque le programme démarre
+(Vous pouvez également utiliser le raccourci &apos;f&apos;).</translation>
     </message>
     <message>
         <source>Auto-save configuration and layout on exit</source>
@@ -336,7 +347,8 @@ Utile pour convertir le nom des notes dans la tonalité d&apos;un instrument (ex
     <message>
         <source>The chosen sampling rate.
 Do not use a too big sampling rate. 22050Hz should be enough in most cases.</source>
-        <translation>Le taux d&apos;échantillonnage choisi. Ne pas utiliser une fréquence d&apos;échantillonage trop élevée. 22050Hz devrait être largement suffisant dans la plupart des cas.</translation>
+        <translation>Le taux d&apos;échantillonnage choisi.
+Ne pas utiliser une fréquence d’échantillonnage trop élevée. 22050Hz devrait être suffisant dans la plupart des cas.</translation>
     </message>
     <message>
         <source>Set the sampling rate to the maximum possible value.</source>
@@ -349,7 +361,8 @@ Do not use a too big sampling rate. 22050Hz should be enough in most cases.</sou
     <message>
         <source>Time between each sound analysis.
 Can be increased to get less CPU usage (but less temporal precision).</source>
-        <translation>Temps entre chaque analyse du son. Augmenter pour réduire l&apos;utilisation du processeur mais baisse la résolution temporelle.</translation>
+        <translation>Temps entre chaque analyse du son.
+Peut être augmenter pour réduire l&apos;utilisation du processeur (mais abaisse la résolution temporelle).</translation>
     </message>
     <message>
         <source>Range of possible notes from the lowest to the highest around the A4 reference note.
@@ -451,7 +464,7 @@ p, li { white-space: pre-wrap; }
 &lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
 p, li { white-space: pre-wrap; }
 &lt;/style&gt;&lt;/head&gt;&lt;body&gt;
-&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Pour accéder à plus d&apos;options, faites un click droit sur les vues pour faire apparaître leurs propriétés !&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
+&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Pour accéder à plus d&apos;options, faites un clic-droit sur chacune des vues pour faire apparaître leurs propriétés !&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
         <source>German</source>
@@ -475,7 +488,7 @@ latine : Do Ré Mi Fa Sol La Si</translation>
     </message>
     <message>
         <source>Transposition</source>
-        <translation type="unfinished"></translation>
+        <translation>Transposition</translation>
     </message>
 </context>
 <context>
@@ -511,21 +524,24 @@ Utile pour convertir des noms de note vers une tonalité d&apos;instrument corre
     <message>
         <source>Range of possible notes from the lowest to the highest around the %1 reference note.
 Smaller the range, smaller the CPU usage.</source>
-        <translation type="unfinished"></translation>
+        <translation>Gamme de notes possibles depuis la plus basse jusqu&apos;à la plus haute autour de la note de référence %1.
+Plus petite est la gamme, plus petite est la consommation processeur.</translation>
     </message>
     <message>
         <source>Lowest semitone from the %1 reference note.
 It can useful to put it higher than -35 to avoid disturbance from the sector alimentation (~50hz).</source>
-        <translation type="unfinished"></translation>
+        <translation>Demi-ton le plus bas à partir de la note de référence %1.
+Ça peut être utile de la mettre au dessus de -35 pour éviter un parasitage provenant de l&apos;alimentation du secteur (~50hz).</translation>
     </message>
     <message>
         <source>Highest semitone from the %1 reference note.</source>
-        <translation type="unfinished"></translation>
+        <translation>Demi-ton le plus haut à partir de la note de référence %1.</translation>
     </message>
     <message>
         <source>Transposition in number of semitones relative to %1.
 Useful to convert note names to a corresponding transposing instrument (e.g. %2 for saxophone, %3 for trumpet).</source>
-        <translation type="unfinished"></translation>
+        <translation>Transposition en nombre de demi-ton relatif à %1.
+Utile pour convertir les noms de note vers une correspondance de transposition d&apos;instrument (ex : %2 pour un saxophone, %3 pour une trompette).</translation>
     </message>
 </context>
 <context>
@@ -842,8 +858,9 @@ r</translation>
         <source>Volume in dB.
 Computed in the frequency domain, from the maximum bin.
 The maximum is reached when the signal energy is maximal NOT when the sound is saturated in the time domain.</source>
-        <translation>Volume en dB. Calculé en domaine fréquenciel, à partir du bin maximum.
-Le maximum de volume est atteint lorsque l&apos;énergie du signal est maximal, pas lorsque la forme d&apos;onde sature dans le domaine temporel.</translation>
+        <translation>Volume en dB.
+Calculé en domaine fréquentiel, à partir du bin maximum.
+Le maximum est atteint lorsque l&apos;énergie du signal est maximal, PAS lorsque le son est saturé dans le domaine temporel.</translation>
     </message>
     <message>
         <source>According to the following colors:
@@ -851,7 +868,7 @@ red       : the capture system is not working.
 grey     : the capture system is OK, but there is not enough sound.
 orange : the analysis conditions are bad (like saturation)
 green   : a note is beeing analyzed and analysis conditions are OK.</source>
-        <translation>Selon les couleurs suivantes:
+        <translation>Selon les couleurs suivantes :
 rouge    : le système de capture ne fonctionne pas.
 gris       : le système de capture est OK, mais le son n&apos;est pas assez fort.
 orange  : les conditions d&apos;analyses ne sont pas suffisantes (ex : il y a saturation).
@@ -890,7 +907,7 @@ vert       : une note est en cours d&apos;analyse et les conditions d&apos;analy
     <name>MicrotonalView</name>
     <message>
         <source>Unkown filename: &apos;</source>
-        <translation>Nom de fichier inconnu: &apos;</translation>
+        <translation>Nom de fichier inconnu : &apos;</translation>
     </message>
     <message>
         <source>Keep root to left side</source>
